#
# spec file for package ossim
#
# Copyright (c) 2020 SUSE LLC
# Copyright (c) 2015 Angelos Tzotsos <tzotsos@opensuse.org>.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define _release_name OrchidIsland
Name:           ossim
Version:        2.11.1
Release:        1.27
Summary:        Open Source Software Image Map (OSSIM)
License:        LGPL-3.0-only
Group:          Development/Libraries/C and C++
URL:            http://trac.osgeo.org/ossim/
Source0:        https://github.com/ossimlabs/ossim/archive/%{_release_name}-%{version}.tar.gz#/%{name}-%{_release_name}-%{version}.tar.gz
BuildRequires:  cmake >= 2.8.0
BuildRequires:  fdupes
BuildRequires:  freetype2-devel
BuildRequires:  gcc-c++
BuildRequires:  geos-devel
BuildRequires:  geotiff-devel
BuildRequires:  hdf5-devel
BuildRequires:  jsoncpp-devel
BuildRequires:  libOpenThreads-devel
BuildRequires:  libcurl-devel
BuildRequires:  libjpeg-devel
BuildRequires:  libtiff-devel
BuildRequires:  zlib-devel

%description
The OSSIM core utilities.
Open Source Software Image Map (OSSIM) is an engine for
remote sensing, image processing, geographical information systems and
photogrammetry.

%package devel
Summary:        Header files for the Open Source Software Image Map
Group:          Development/Libraries/C and C++
Requires:       lib%{name}1 = %{version}-%{release}
Provides:       lib%{name}-devel

%description devel
The OSSIM development files.
Open Source Software Image Map (OSSIM) is an engine for
remote sensing, image processing, geographical information systems and
photogrammetry.

%package -n lib%{name}1
Summary:        Open Source Software Image Map libraries
Group:          System/Libraries

%description -n lib%{name}1
The OSSIM shared library files.
Open Source Software Image Map (OSSIM) is an engine for
remote sensing, image processing, geographical information systems and
photogrammetry.

%package sample-data
Summary:        OSSIM data samples files
Group:          Development/Libraries/C and C++

%description sample-data
The OSSIM data samples files for tests.

%prep
%setup -q -n %{name}-%{_release_name}-%{version}

%build
export CXXFLAGS=" -std=c++03"
%cmake \
  -DBUILD_OSSIM_FRAMEWORKS=ON \
  -DBUILD_OSSIM_FREETYPE_SUPPORT=ON \
  -DBUILD_OSSIM_MPI_SUPPORT=OFF \
  -DBUILD_OSSIM_ID_SUPPORT=ON \
  -DBUILD_OSSIM_APPS=ON \
  -DBUILD_OSSIM_CURL_APPS=OFF \
  -DBUILD_OSSIM_TESTS=ON \
  -DBUILD_OSSIM_HDF5_SUPPORT=ON \
  -DBUILD_SHARED_LIBS=ON

make %{?_smp_mflags}

%install
%cmake_install

# Fix lib folder for 32-bits
# Beware don't let spec-cleaner playing with this
%if "%{_lib}" == "lib"
mkdir -p %{buildroot}/usr/lib
mv %{buildroot}/usr/lib64/* %{buildroot}/usr/lib/
%endif

%fdupes %{buildroot}/%{_prefix}

%post -n lib%{name}1 -p /sbin/ldconfig

%postun -n lib%{name}1 -p /sbin/ldconfig

%files -n lib%{name}1
%defattr(644,root,root,755)
%{_libdir}/*.so.*

%files
%defattr(-,root,root,-)
%{_bindir}/*

%files devel
%defattr(-,root,root,-)
%{_includedir}/*
%{_libdir}/lib*.so

%files sample-data
%dir %{_datadir}/ossim
%{_datadir}/ossim/*

%changelog
* Thu Feb 20 2020 Dirk Stoecker <opensuse@dstoecker.de>
- update to 2.11.1
- drop fix_hdf5_printErrorStack.patch (fixed upstream)
* Sat Jul  6 2019 Jan Engelhardt <jengelh@inai.de>
- Ensure neutrality of descriptions. Trim history from
  descriptions.
- Limit fdupes to the /usr subvolume.
* Fri Mar 22 2019 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Switch from geos35 to geos as there is no more build problem
  with Leap 42.3, it also fixes build on Leap 15.0
* Sun Sep 30 2018 Bruno Friedmann <bruno@ioda-net.ch>
- Update to last 2.5.1 version (Islamorada)
- Packaging:
  + spec-cleaner minimal, but don't let it play with the manual
    patching for lib(64)
  + add patch fix_hdf5_printErrorStack.patch to replace deprecated
    and removed printError() function in hdf5 1.10.2+
* Sat Sep 29 2018 Bruno Friedmann <bruno@ioda-net.ch>
- Fix build with Tumbleweed (force use of '-std=c++03')
  Backport old patch lost during transfert in App:Geo from
  Staging
* Tue May 29 2018 guillaume.gardet@opensuse.org
- Update to 2.3.2
- Drop cmake.patch
* Mon Nov 13 2017 guillaume@opensuse.org
- Update to 2.1.0 (lib version 1.9.0)
* Mon Nov 13 2017 guillaume@opensuse.org
- Fix build with Tumbleweed (force use of '-std=c++03')
* Wed Jun 28 2017 guillaume@opensuse.org
- Update cmake.patch to match 1.8.20.3 version (instead of old
  1.8.18.1)
* Tue Jun 27 2017 guillaume@opensuse.org
- Build against geos 3.5 (instead of 3.6) to fix openSUSE Leap 42.x
  builds
* Sun Dec 27 2015 mpluskal@suse.com
- Use cmake macros
- Shorten summary
- Do not ship static library
* Wed Dec 23 2015 Angelos Tzotsos <tzotsos@opensuse.org>
- Update to 1.8.20
* Fri Aug 14 2015 Angelos Tzotsos <tzotsos@opensuse.org>
- Initial build
- Patch cmake.patch to allow proper cmake build
